from setuptools import setup

setup(name='distributions-brc',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author='Bruno Cabral',
      author_email='cabral.brc@gmail.com',
      zip_safe=False)
